| Title: | Obtaining Open Data from Instituto Canario De Estadistica (ISTAC) API |
|---|---|
| Description: | You can access to open data published in Instituto Canario De Estadistica (ISTAC) APIs at <https://datos.canarias.es/api/estadisticas/>. |
| Authors: | Alberto Gonzalez [cph], Elisa Jorge [aut, cre] |
| Maintainer: | Elisa Jorge <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.3.0 |
| Built: | 2026-06-02 08:57:44 UTC |
| Source: | https://github.com/cran/istacr |
This function returns a list of indicators published in the ISTAC-indicators database. An indicator is a measure used to know the intensity of a phenomenon in spacetime. This measure can refer to different spatial or temporal granularities.
get_indicators( q = "", order = "", limit = 25, offset = 0, fields = "", representation = "" )get_indicators( q = "", order = "", limit = 25, offset = 0, fields = "", representation = "" )
q |
(string): Metadata query on which the searches can be built using |
order |
(string): Order. Possible values are: |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
fields |
(string): Use of the answer by adding new fields. Possible values are: |
representation |
(string): Allows filtering the observations by their value. Its use only makes sense when |
get_indicators( q='id IN ("AFILIACIONES", "EMPLEO_REGISTRADO_AGRICULTURA")', order="id ASC", fields="+data", representation="GEOGRAPHICAL[35003|35005], MEASURE[ABSOLUTE]" )get_indicators( q='id IN ("AFILIACIONES", "EMPLEO_REGISTRADO_AGRICULTURA")', order="id ASC", fields="+data", representation="GEOGRAPHICAL[35003|35005], MEASURE[ABSOLUTE]" )
This function returns the metadata that describe the characteristics of a specific indicator, allowing the compression of the measured fact; also through the data request the complete data (for all spacetime) of the indicator is provided.
get_indicators_code(indicatorcode)get_indicators_code(indicatorcode)
indicatorcode |
(string): an indicator code |
get_indicators_code("IPI_BASE_2021") get_indicators_code("IPI")get_indicators_code("IPI_BASE_2021") get_indicators_code("IPI")
This function returns complete data (for all spacetime) of the indicator. On the other hand, metadata describing the characteristics of a specific indicator are offered through the metadata request, allowing the compression of the measured fact.
get_indicators_code_data( indicatorcode, representation = "", granularity = "", fields = "", as_dataframe = T )get_indicators_code_data( indicatorcode, representation = "", granularity = "", fields = "", as_dataframe = T )
indicatorcode |
(string): an indicator code |
representation |
(string): Allows filtering the observations by their value. |
granularity |
(string): Allows to filter the observations through the granularities of the same. |
fields |
(string): Allows you to customize the response by excluding fields. The possible values are:
|
as_dataframe |
(bool): If True, this function returns a namedtuple with:
|
get_indicators_code_data("IPC")get_indicators_code_data("IPC")
This function returns a list of geographic granularities treated in the ISTAC-indicators database. For example provincial, insular or municipal granularity.
get_indicators_geographic_granularities()get_indicators_geographic_granularities()
get_indicators_geographic_granularities()get_indicators_geographic_granularities()
This function returns values of a geographical granularity that in turn are part of a specific theme or system of indicators.
get_indicators_geographical_values( geographicalgranularitycode, subjectcode, systemcode = "" )get_indicators_geographical_values( geographicalgranularitycode, subjectcode, systemcode = "" )
geographicalgranularitycode |
(string): geographical granularity code |
subjectcode |
(string): subject code |
systemcode |
(string): system code |
get_indicators_geographical_values( "REGIONS", subjectcode="051", systemcode="C00067A" )get_indicators_geographical_values( "REGIONS", subjectcode="051", systemcode="C00067A" )
This function returns all subjects which the ISTAC classifies its statistical operations.
get_indicators_subjects()get_indicators_subjects()
get_indicators_subjects()get_indicators_subjects()
This function returns a list of indicator systems published in the ISTAC-indicators database. The indicators are simple or compound statistics, however a single indicator can rarely provide useful information about complex phenomena such as the economic situation, living conditions, schooling or others. Indicator systems are generally designed to generate more and more accurate information about the conditions of a phenomenon; and for this they are organized in dimensions or areas of analysis, under which the indicators are integrated.
get_indicators_systems(limit = 25, offset = 0)get_indicators_systems(limit = 25, offset = 0)
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
get_indicators_systems()get_indicators_systems()
This function returns metadata of a system of indicators published in the ISTAC-indicators database. The indicators are simple or compound statistics, however a single indicator can rarely provide useful information about complex phenomena such as the economic situation, living conditions, schooling or others.
get_indicators_systems_code(indicatorsystemcode)get_indicators_systems_code(indicatorsystemcode)
indicatorsystemcode |
(string): an indicator system code |
get_indicators_systems_code("C00075H")get_indicators_systems_code("C00075H")
This function returns instances of indicators associated with a specific indicator system. An instance of an indicator is nothing more than a spatio-temporal query of an indicator when it is incorporated into a specific indicator system.
get_indicators_systems_code_instances( indicatorsystemcode, q = "", order = "", limit = 25, offset = 0, fields = "", representation = "", granularity = "" )get_indicators_systems_code_instances( indicatorsystemcode, q = "", order = "", limit = 25, offset = 0, fields = "", representation = "", granularity = "" )
indicatorsystemcode |
(string): with an indicator system code |
q |
(string): Query of metadata on which the searches can be built are: |
order |
(string): Order. Possible values are: |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
fields |
(string): Use of the answer by adding new fields. Possible values are: |
representation |
(string): Allows filtering the observations by their value. Its use only makes sense when |
granularity |
(string): Allows to filter the observations through the granularities of the same. Its use only makes sense when |
get_indicators_systems_code_instances("C00075H") get_indicators_systems_code_instances( "C00075H", q='id EQ "INDICADORES_MUNICIPALES"' )get_indicators_systems_code_instances("C00075H") get_indicators_systems_code_instances( "C00075H", q='id EQ "INDICADORES_MUNICIPALES"' )
This function returns metadata of an indicator set associated with a specific indicator system. An instance of an indicator is nothing more than a spatio-temporal query of an indicator when it is incorporated into a specific indicator system.
get_indicators_systems_code_instances_code( indicatorsystemcode, indicatorinstancecode )get_indicators_systems_code_instances_code( indicatorsystemcode, indicatorinstancecode )
indicatorsystemcode |
(string) indicator system code |
indicatorinstancecode |
(string) indicator instance code |
get_indicators_systems_code_instances_code( "C00075H", "21af0477-d63b-493b-ad02-4ab181547223" )get_indicators_systems_code_instances_code( "C00075H", "21af0477-d63b-493b-ad02-4ab181547223" )
This function returns metadata of an indicator set associated with a specific indicator system. An instance of an indicator is nothing more than a spatio-temporal query of an indicator when it is incorporated into a specific indicator system.
get_indicators_systems_code_instances_code_data( indicatorsystemcode, indicatorinstancecode, representation = "", granularity = "", fields = "" )get_indicators_systems_code_instances_code_data( indicatorsystemcode, indicatorinstancecode, representation = "", granularity = "", fields = "" )
indicatorsystemcode |
(string): Indicator system code |
indicatorinstancecode |
(string): Indicator instance code |
representation |
(string): Allows filtering the observations by their value. |
granularity |
(string): Allows to filter the observations through the granularities of the same. |
fields |
(string): Allows you to customize the response by excluding fields. The possible values are: |
get_indicators_systems_code_instances_code_data( "C00075H", "21af0477-d63b-493b-ad02-4ab181547223" )get_indicators_systems_code_instances_code_data( "C00075H", "21af0477-d63b-493b-ad02-4ab181547223" )
This function returns a list of temporary granularity treated in the ISTAC data bank-indicators ordered from highest to lowest granularity. For example annual, quarterly or monthly granularity.
get_indicators_time_granularities()get_indicators_time_granularities()
get_indicators_time_granularities()get_indicators_time_granularities()
This function allows consulting all existing statistical data cubes.
get_statisticalresources_datasets( lang = "es", limit = 25, offset = 0, orderby = "", query = "" )get_statisticalresources_datasets( lang = "es", limit = 25, offset = 0, orderby = "", query = "" )
lang |
(string): Language in which you want to get the answer. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
orderby |
(string): Order. Possible values are |
query |
(string): Metadata query on which the searches can be built. |
get_statisticalresources_datasets(limit=5)get_statisticalresources_datasets(limit=5)
This function allows to consult all the data sets maintained by a certain organization.
get_statisticalresources_datasets_agency( agencyid, lang = "es", limit = 25, offset = 0, orderby = "", query = "" )get_statisticalresources_datasets_agency( agencyid, lang = "es", limit = 25, offset = 0, orderby = "", query = "" )
agencyid |
(string): Identifier of the maintainer organization of the resource. A possible value is |
lang |
(string): Language in which you want to get the answer. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
orderby |
(string): Order. Possible values are |
query |
(string): Metadata query on which the searches can be built. |
get_statisticalresources_datasets_agency(agencyid="ISTAC")get_statisticalresources_datasets_agency(agencyid="ISTAC")
This function allows to obtain all the versions of a statistical cube with a certain identifier and that also maintains a certain organization.
get_statisticalresources_datasets_agency_resource( agencyid, resourceid, lang = "es", limit = 25, offset = 0, orderby = "", query = "" )get_statisticalresources_datasets_agency_resource( agencyid, resourceid, lang = "es", limit = 25, offset = 0, orderby = "", query = "" )
agencyid |
(string): Identifier of the maintainer organization of the resource. A possible value is |
resourceid |
(string): Resource identifier. A possible value is |
lang |
(string): Language in which you want to get the answer. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
orderby |
(string): Order. Possible values are |
query |
(string): Metadata query on which the searches can be built. |
get_statisticalresources_datasets_agency_resource( agencyid="ISTAC", resourceid="C00010A_000002" )get_statisticalresources_datasets_agency_resource( agencyid="ISTAC", resourceid="C00010A_000002" )
This function allows to obtain a certain version of a statistical cube with a certain identifier and that also maintains a certain organization.
get_statisticalresources_datasets_agency_resource_version( agencyid, resourceid, version, dim = "", fields = "", lang = "es", as_dataframe = T )get_statisticalresources_datasets_agency_resource_version( agencyid, resourceid, version, dim = "", fields = "", lang = "es", as_dataframe = T )
agencyid |
(string): Identifier of the maintainer organization of the resource. A possible value is |
resourceid |
(string): Resource identifier. A possible value is |
version |
(string): Resource version. A possible value is |
dim |
(string): Allows filtering the data obtained in the response. A example is |
fields |
(string): Allows you to customize the response by excluding fields from it. The possible values are |
lang |
(string): Language in which you want to get the answer. |
as_dataframe |
(bool): If True, this function returns a namedtuple with:
|
get_statisticalresources_datasets_agency_resource_version( agencyid="ISTAC", resourceid="E30050A_000007", version="~latest", dim="TIME_PERIOD:2025-M01:MEDIDAS:IPI_BASE_2021:TERRITORIO:ES70")get_statisticalresources_datasets_agency_resource_version( agencyid="ISTAC", resourceid="E30050A_000007", version="~latest", dim="TIME_PERIOD:2025-M01:MEDIDAS:IPI_BASE_2021:TERRITORIO:ES70")
This function allows consulting all existing statistical queries.
get_statisticalresources_queries( lang = "es", limit = 25, offset = 0, orderby = "", query = "" )get_statisticalresources_queries( lang = "es", limit = 25, offset = 0, orderby = "", query = "" )
lang |
(string): Language in which you want to get the answer. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
orderby |
(string): Order. Possible values are |
query |
(string): Metadata query on which the searches can be built. |
get_statisticalresources_queries(limit=5)get_statisticalresources_queries(limit=5)
This function allows to consult all the queries maintained by a certain organization.
get_statisticalresources_queries_agency( agencyid, lang = "es", limit = 25, offset = 0, orderby = "", query = "" )get_statisticalresources_queries_agency( agencyid, lang = "es", limit = 25, offset = 0, orderby = "", query = "" )
agencyid |
(string): Identifier of the maintainer organization of the resource. A possible value is |
lang |
(string): Language in which you want to get the answer. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
orderby |
(string): Order. Possible values are |
query |
(string): Metadata query on which the searches can be built. |
get_statisticalresources_queries_agency(agencyid="ISTAC", limit=5)get_statisticalresources_queries_agency(agencyid="ISTAC", limit=5)
This function allows to obtain final data of a statistical query with a certain identifier and that also maintains a certain organization.
get_statisticalresources_queries_agency_resource( agencyid, resourceid, fields = "", lang = "es", as_dataframe = T )get_statisticalresources_queries_agency_resource( agencyid, resourceid, fields = "", lang = "es", as_dataframe = T )
agencyid |
(string): Identifier of the maintainer organization of the resource. A possible value is |
resourceid |
(string): Resource identifier. A possible value is |
fields |
(string): Allows you to customize the response by excluding fields from it.
|
lang |
(string): Language in which you want to get the answer. |
as_dataframe |
(bool): If True, this function returns a namedtuple with:
|
get_statisticalresources_queries_agency_resource( agencyid="ISTAC", resourceid="C00005A_000004" )get_statisticalresources_queries_agency_resource( agencyid="ISTAC", resourceid="C00005A_000004" )
This function returns the content from /v1.0/categorisations
get_structuralresources_categorisations( limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_categorisations( limit = 25, offset = 0, query = "", orderby = "" )
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_categorisations() get_structuralresources_categorisations( query="ID EQ 2090", orderby="ID ASC" )get_structuralresources_categorisations() get_structuralresources_categorisations( query="ID EQ 2090", orderby="ID ASC" )
This function returns the content from /v1.0/categorisations/{agencyID}
get_structuralresources_categorisations_agency( agencyid, limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_categorisations_agency( agencyid, limit = 25, offset = 0, query = "", orderby = "" )
agencyid |
(string): Identifier of the agency that publishes. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_categorisations_agency("ISTAC")get_structuralresources_categorisations_agency("ISTAC")
This function returns the content from /v1.0/categorisations/{agencyID}/{resourceID}
get_structuralresources_categorisations_agency_resource( agencyid, resourceid, limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_categorisations_agency_resource( agencyid, resourceid, limit = 25, offset = 0, query = "", orderby = "" )
agencyid |
(string): Identifier of the agency that publishes. |
resourceid |
(string): Resource identifier. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_categorisations_agency_resource("ISTAC", "cat2")get_structuralresources_categorisations_agency_resource("ISTAC", "cat2")
This function returns the content from /v1.0/categorisations/{agencyID}/{resourceID}/{version}
get_structuralresources_categorisations_agency_resource_version( agencyid, resourceid, version )get_structuralresources_categorisations_agency_resource_version( agencyid, resourceid, version )
agencyid |
(string): Identifier of the agency that publishes. |
resourceid |
(string): Resource identifier. |
version |
(string): Specific version of the resource. |
get_structuralresources_categorisations_agency_resource_version( "ISTAC", "cat2", "01.000" )get_structuralresources_categorisations_agency_resource_version( "ISTAC", "cat2", "01.000" )
This function returns the content from /v1.0/categoryschemes
get_structuralresources_category_schemes( limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_category_schemes( limit = 25, offset = 0, query = "", orderby = "" )
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_category_schemes() get_structuralresources_category_schemes( query="ID EQ 2090", orderby="ID ASC" )get_structuralresources_category_schemes() get_structuralresources_category_schemes( query="ID EQ 2090", orderby="ID ASC" )
This function returns the content from /v1.0/categoryschemes/{agencyID}
get_structuralresources_category_schemes_agency( agencyid, limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_category_schemes_agency( agencyid, limit = 25, offset = 0, query = "", orderby = "" )
agencyid |
(string): Identifier of the agency that publishes. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_category_schemes_agency( "ISTAC", query="ID EQ 2090", orderby="ID ASC" )get_structuralresources_category_schemes_agency( "ISTAC", query="ID EQ 2090", orderby="ID ASC" )
This function returns the content from /v1.0/categoryschemes/{agencyID}/{resourceID}
get_structuralresources_category_schemes_agency_resource( agencyid, resourceid, limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_category_schemes_agency_resource( agencyid, resourceid, limit = 25, offset = 0, query = "", orderby = "" )
agencyid |
(string): Identifier of the agency that publishes. |
resourceid |
(string): Resource identifier. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_category_schemes_agency_resource( "ISTAC", "TEMAS_CANARIAS" )get_structuralresources_category_schemes_agency_resource( "ISTAC", "TEMAS_CANARIAS" )
This function returns the content from /v1.0/categoryschemes/{agencyID}/{resourceID}/{version}
get_structuralresources_category_schemes_agency_resource_version( agencyid, resourceid, version )get_structuralresources_category_schemes_agency_resource_version( agencyid, resourceid, version )
agencyid |
(string): Identifier of the agency that publishes. |
resourceid |
(string): Resource identifier. |
version |
(string): Specific version of the resource. |
get_structuralresources_category_schemes_agency_resource_version( "ISTAC", "TEMAS_CANARIAS", "01.000" )get_structuralresources_category_schemes_agency_resource_version( "ISTAC", "TEMAS_CANARIAS", "01.000" )
This function returns the content from /v1.0/categoryschemes/{agencyID}/{resourceID}/{version}/categories
get_structuralresources_category_schemes_agency_resource_version_categories( agencyid, resourceid, version, limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_category_schemes_agency_resource_version_categories( agencyid, resourceid, version, limit = 25, offset = 0, query = "", orderby = "" )
agencyid |
(string): Identifier of the agency that publishes. |
resourceid |
(string): Resource identifier. |
version |
(string): Specific version of the resource. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_category_schemes_agency_resource_version_categories( "ISTAC", "TEMAS_CANARIAS", "01.000" )get_structuralresources_category_schemes_agency_resource_version_categories( "ISTAC", "TEMAS_CANARIAS", "01.000" )
This function returns the content from /v1.0/categoryschemes/{agencyID}/{resourceID}/{version}/categories/{categoryID}
get_structuralresources_category_schemes_agency_resource_version_categories_id( agencyid, resourceid, version, categoryid )get_structuralresources_category_schemes_agency_resource_version_categories_id( agencyid, resourceid, version, categoryid )
agencyid |
(string): Identifier of the agency that publishes. |
resourceid |
(string): Resource identifier. |
version |
(string): Specific version of the resource. |
categoryid |
(string): category identifier. |
get_structuralresources_category_schemes_agency_resource_version_categories_id( "ISTAC", "TEMAS_CANARIAS", "01.000", "060" ) get_structuralresources_category_schemes_agency_resource_version_categories_id( "ISTAC", "TEMAS_CANARIAS", "01.000", "060.060_010.060_010_010" )get_structuralresources_category_schemes_agency_resource_version_categories_id( "ISTAC", "TEMAS_CANARIAS", "01.000", "060" ) get_structuralresources_category_schemes_agency_resource_version_categories_id( "ISTAC", "TEMAS_CANARIAS", "01.000", "060.060_010.060_010_010" )
This function returns the list of families of classifications
get_structuralresources_codelist_families( limit = 25, offset = 0, orderby = "", query = "" )get_structuralresources_codelist_families( limit = 25, offset = 0, orderby = "", query = "" )
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
orderby |
(string): Field by which to sort the results. |
query |
(string): Query to filter the results. |
get_structuralresources_codelist_families()get_structuralresources_codelist_families()
This function allows to obtain a family of classifications in particular.
get_structuralresources_codelist_families_id(id)get_structuralresources_codelist_families_id(id)
id |
(string): codelist family identificator |
get_structuralresources_codelist_families_id('CODELIST_ID')get_structuralresources_codelist_families_id('CODELIST_ID')
This function allows to obtain the list of classifications.
get_structuralresources_codelists( limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_codelists( limit = 25, offset = 0, query = "", orderby = "" )
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_codelists()get_structuralresources_codelists()
This function allows obtaining the list of all the classifications maintained by a certain organization.
get_structuralresources_codelists_agency( agencyid, limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_codelists_agency( agencyid, limit = 25, offset = 0, query = "", orderby = "" )
agencyid |
(string): Agency identificator. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_codelists_agency("ISTAC") get_structuralresources_codelists_agency("ESTAT")get_structuralresources_codelists_agency("ISTAC") get_structuralresources_codelists_agency("ESTAT")
This function allows to obtain all the versions of a classification with a certain identifier and that is also kept by a certain organization.
get_structuralresources_codelists_agency_resource( agencyid, resourceid, limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_codelists_agency_resource( agencyid, resourceid, limit = 25, offset = 0, query = "", orderby = "" )
agencyid |
(string): Agency identificator. |
resourceid |
(string): Resource identificator. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_codelists_agency_resource("ISTAC", "CL_AREA_ES")get_structuralresources_codelists_agency_resource("ISTAC", "CL_AREA_ES")
This function allows you to consult a particular version of a classification.
get_structuralresources_codelists_agency_resource_version( agencyid, resourceid, version )get_structuralresources_codelists_agency_resource_version( agencyid, resourceid, version )
agencyid |
(string): Agency identificator. |
resourceid |
(string): Resource identificator. |
version |
(string): Specific resource version. |
get_structuralresources_codelists_agency_resource_version( "ISTAC", "CL_AREA_ES", "01.000" )get_structuralresources_codelists_agency_resource_version( "ISTAC", "CL_AREA_ES", "01.000" )
This function allows to consult the codes of a version of a classification. Note that
if wildcards are used as ~all or one of the limit, offset, query or
orderBy parameters, the list will be automatically paginated.
get_structuralresources_codelists_agency_resource_version_codes( agencyid, resourceid, version, limit = 1000, offset = 0, query = "", orderby = "", openness = "", order = "", fields = "", lang = "es", as_dataframe = T )get_structuralresources_codelists_agency_resource_version_codes( agencyid, resourceid, version, limit = 1000, offset = 0, query = "", orderby = "", openness = "", order = "", fields = "", lang = "es", as_dataframe = T )
agencyid |
(string): Agency identificator. |
resourceid |
(string): Resource identificator. |
version |
(string): Specific resource version. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. orderby (string): Field by which to sort the results. |
orderby |
(string): Order established for data. |
openness |
(string): Opening established for viewing. |
order |
(string): Order established for visualization. |
fields |
(string): Additional fields that you want to show in the answer. |
lang |
(string): Language in which you want to get the answer. |
as_dataframe |
(bool): If True, this function returns a pandas dataframe built from API response. |
get_structuralresources_codelists_agency_resource_version_codes( "ISTAC", "CL_AREA_ES", "01.000" )get_structuralresources_codelists_agency_resource_version_codes( "ISTAC", "CL_AREA_ES", "01.000" )
This function allows to consult a specific code of a version of a classification.
get_structuralresources_codelists_agency_resource_version_codes_codeid( agencyid, resourceid, version, codeid )get_structuralresources_codelists_agency_resource_version_codes_codeid( agencyid, resourceid, version, codeid )
agencyid |
(string): Agency identificator. |
resourceid |
(string): Resource identificator. |
version |
(string): Specific resource version. |
codeid |
(string): Code identificator. |
get_structuralresources_codelists_agency_resource_version_codes_codeid( "ISTAC", "CL_AREA_ES", "01.000", "ES706A01")get_structuralresources_codelists_agency_resource_version_codes_codeid( "ISTAC", "CL_AREA_ES", "01.000", "ES706A01")
This function allows to see changes between two classifications.
get_structuralresources_codelists_agency_resource_version_recode( agencyid, resourceid, version, referenceagencyid, referenceresourceid, referenceversion )get_structuralresources_codelists_agency_resource_version_recode( agencyid, resourceid, version, referenceagencyid, referenceresourceid, referenceversion )
agencyid |
(string): Agency identificator. |
resourceid |
(string): Resource identificator. |
version |
(string): Specific resource version. |
referenceagencyid |
(string): Reference agency identificator. |
referenceresourceid |
(string): Reference resource identificator. |
referenceversion |
(string): Reference specific resource version. |
get_structuralresources_codelists_agency_resource_version_recode( "ISTAC", "CL_AREA_ES", "01.001", "ISTAC", "CL_AREA_ES_RELATIVA", "~latest" )get_structuralresources_codelists_agency_resource_version_recode( "ISTAC", "CL_AREA_ES", "01.001", "ISTAC", "CL_AREA_ES_RELATIVA", "~latest" )
This function allows you to consult any restrictions for a specific code of a version of a classification.
get_structuralresources_codelists_agency_resource_version_restrictions( agencyid, resourceid, version )get_structuralresources_codelists_agency_resource_version_restrictions( agencyid, resourceid, version )
agencyid |
(string): Agency identificator. |
resourceid |
(string): Resource identificator. |
version |
(string): Specific resource version. |
get_structuralresources_codelists_agency_resource_version_restrictions( "ISTAC", "CL_AREA_ES", "~latest" )get_structuralresources_codelists_agency_resource_version_restrictions( "ISTAC", "CL_AREA_ES", "~latest" )
This function returns the content from /v1.0/conceptschemes
get_structuralresources_concept_schemes( limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_concept_schemes( limit = 25, offset = 0, query = "", orderby = "" )
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_concept_schemes() get_structuralresources_concept_schemes( query="ID EQ 2090", orderby="ID ASC" )get_structuralresources_concept_schemes() get_structuralresources_concept_schemes( query="ID EQ 2090", orderby="ID ASC" )
This function returns the content from /v1.0/conceptschemes/{agencyID}
get_structuralresources_concept_schemes_agency( agencyid, limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_concept_schemes_agency( agencyid, limit = 25, offset = 0, query = "", orderby = "" )
agencyid |
(string): Identifier of the agency that publishes. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_concept_schemes_agency("ISTAC") get_structuralresources_concept_schemes_agency( "ESTAT", query="ID EQ 2090", orderby="ID ASC" )get_structuralresources_concept_schemes_agency("ISTAC") get_structuralresources_concept_schemes_agency( "ESTAT", query="ID EQ 2090", orderby="ID ASC" )
This function returns the content from /v1.0/conceptschemes/{agencyID}/{resourceID}
get_structuralresources_concept_schemes_agency_resource( agencyid, resourceid, limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_concept_schemes_agency_resource( agencyid, resourceid, limit = 25, offset = 0, query = "", orderby = "" )
agencyid |
(string): Identifier of the agency that publishes. |
resourceid |
(string): Resource identifier. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_concept_schemes_agency_resource( agencyid="ISTAC", resourceid="CSM_C00010A_SIE" )get_structuralresources_concept_schemes_agency_resource( agencyid="ISTAC", resourceid="CSM_C00010A_SIE" )
This function returns the content from /v1.0/conceptschemes/{agencyID}/{resourceID}/{version}
get_structuralresources_concept_schemes_agency_resource_version( agencyid, resourceid, version )get_structuralresources_concept_schemes_agency_resource_version( agencyid, resourceid, version )
agencyid |
(string) Identifier of the agency that publishes. |
resourceid |
(string) Resource identifier. |
version |
(string) Specific version of the resource. |
get_structuralresources_concept_schemes_agency_resource_version( agencyid="ISTAC", resourceid="CSM_C00010A_SIE", version="01.000" )get_structuralresources_concept_schemes_agency_resource_version( agencyid="ISTAC", resourceid="CSM_C00010A_SIE", version="01.000" )
This function returns the content from
/v1.0/conceptschemes/{agencyID}/{resourceID}/{version}/concepts
get_structuralresources_concept_schemes_agency_resource_version_concepts( agencyid, resourceid, version, limit = 25, offset = 0, query = "", orderby = "", fields = "" )get_structuralresources_concept_schemes_agency_resource_version_concepts( agencyid, resourceid, version, limit = 25, offset = 0, query = "", orderby = "", fields = "" )
agencyid |
(string): Identifier of the agency that publishes. |
resourceid |
(string): Resource identifier. |
version |
(string): Specific version of the resource. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
fields |
(string): Additional fields that you want to show in the answer. |
get_structuralresources_concept_schemes_agency_resource_version_concepts( agencyid="ISTAC", resourceid="CSM_C00010A_SIE", version="01.000" )get_structuralresources_concept_schemes_agency_resource_version_concepts( agencyid="ISTAC", resourceid="CSM_C00010A_SIE", version="01.000" )
This function returns the content from
/v1.0/conceptschemes/{agencyID}/{resourceID}/{version}/concepts/{conceptID}
get_structuralresources_concept_schemes_agency_resource_version_concepts_id( agencyid, resourceid, version, conceptid )get_structuralresources_concept_schemes_agency_resource_version_concepts_id( agencyid, resourceid, version, conceptid )
agencyid |
(string): Identifier of the agency that publishes. |
resourceid |
(string): Resource identifier. |
version |
(string): Specific version of the resource. |
conceptid |
(string): Concept identifier. |
get_structuralresources_concept_schemes_agency_resource_version_concepts_id( agencyid="ISTAC", resourceid="CSM_C00010A_SIE", version="01.000", conceptid="ELECTORES" )get_structuralresources_concept_schemes_agency_resource_version_concepts_id( agencyid="ISTAC", resourceid="CSM_C00010A_SIE", version="01.000", conceptid="ELECTORES" )
This function returns the content from /v1.0/conceptTypes
get_structuralresources_concept_types()get_structuralresources_concept_types()
get_structuralresources_concept_types()get_structuralresources_concept_types()
This function returns the content from /v1.0/contentConstraints
get_structuralresources_content_constraints( limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_content_constraints( limit = 25, offset = 0, query = "", orderby = "" )
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_content_constraints() get_structuralresources_content_constraints( query="ID EQ 2090", orderby="ID ASC" )get_structuralresources_content_constraints() get_structuralresources_content_constraints( query="ID EQ 2090", orderby="ID ASC" )
This function returns the content from /v1.0/contentConstraints/{agencyID}
get_structuralresources_content_constraints_agency( agencyid, limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_content_constraints_agency( agencyid, limit = 25, offset = 0, query = "", orderby = "" )
agencyid |
(string): Identifier of the agency that publishes. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_content_constraints_agency("ISTAC")get_structuralresources_content_constraints_agency("ISTAC")
This function returns the content from /v1.0/contentConstraints/{agencyID}/{resourceID}
get_structuralresources_content_constraints_agency_resource( agencyid, resourceid, limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_content_constraints_agency_resource( agencyid, resourceid, limit = 25, offset = 0, query = "", orderby = "" )
agencyid |
(string): Identifier of the agency that publishes. |
resourceid |
(string): Resource identifier. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_content_constraints_agency_resource( "ISTAC", "CSM_C00010A_SIE" )get_structuralresources_content_constraints_agency_resource( "ISTAC", "CSM_C00010A_SIE" )
This function returns the content from /v1.0/contentConstraints/{agencyID}/{resourceID}/{version}
get_structuralresources_content_constraints_agency_resource_version( agencyid, resourceid, version )get_structuralresources_content_constraints_agency_resource_version( agencyid, resourceid, version )
agencyid |
(string): Identifier of the agency that publishes. |
resourceid |
(string): Resource identifier. |
version |
(string): Specific version of the resource. |
get_structuralresources_content_constraints_agency_resource_version( "ISTAC", "CSM_C00010A_SIE", "01.000" )get_structuralresources_content_constraints_agency_resource_version( "ISTAC", "CSM_C00010A_SIE", "01.000" )
This function returns the content from
/v1.0/contentConstraints/{agencyID}/{resourceID}/{version}/regions/{regionCode}
get_structuralresources_content_constraints_agency_resource_version_regions( regioncode, agencyid, resourceid, version )get_structuralresources_content_constraints_agency_resource_version_regions( regioncode, agencyid, resourceid, version )
regioncode |
(string) Region code. |
agencyid |
(string) Identifier of the agency that publishes. |
resourceid |
(string) Resource identifier. |
version |
(string) Specific version of the resource. |
get_structuralresources_content_constraints_agency_resource_version_regions( "0001", "ISTAC", "CSM_C00010A_SIE", "01.000" )get_structuralresources_content_constraints_agency_resource_version_regions( "0001", "ISTAC", "CSM_C00010A_SIE", "01.000" )
This function returns the content from /v1.0/datastructures
get_structuralresources_data_structures( limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_data_structures( limit = 25, offset = 0, query = "", orderby = "" )
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_data_structures() get_structuralresources_data_structures( query="ID EQ 2090", orderby="ID ASC" )get_structuralresources_data_structures() get_structuralresources_data_structures( query="ID EQ 2090", orderby="ID ASC" )
This function returns the content from /v1.0/datastructures/{agencyID}
get_structuralresources_data_structures_agency( agencyid, limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_data_structures_agency( agencyid, limit = 25, offset = 0, query = "", orderby = "" )
agencyid |
(string): Identifier of the agency that publishes. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_data_structures_agency("ISTAC")get_structuralresources_data_structures_agency("ISTAC")
This function returns the content from /v1.0/datastructures/{agencyID}/{resourceID}
get_structuralresources_data_structures_agency_resource( agencyid, resourceid, limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_data_structures_agency_resource( agencyid, resourceid, limit = 25, offset = 0, query = "", orderby = "" )
agencyid |
(string): Identifier of the agency that publishes. |
resourceid |
(string): Resource identifier. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_data_structures_agency_resource( "ISTAC", "DSD_C00010A_00001" )get_structuralresources_data_structures_agency_resource( "ISTAC", "DSD_C00010A_00001" )
This function returns the content from
/v1.0/datastructures/{agencyID}/{resourceID}/{version}
get_structuralresources_data_structures_agency_resource_version( agencyid, resourceid, version )get_structuralresources_data_structures_agency_resource_version( agencyid, resourceid, version )
agencyid |
(string): Identifier of the agency that publishes. |
resourceid |
(string): Resource identifier. |
version |
(string): Specific version of the resource. |
get_structuralresources_data_structures_agency_resource_version( "ISTAC", "DSD_C00010A_00001", "01.001" )get_structuralresources_data_structures_agency_resource_version( "ISTAC", "DSD_C00010A_00001", "01.001" )
This function returns data from
/v1.0/variables/{variableID}/variableelements/{resourceID}/geoinfo
get_structuralresources_geoinfo( variableid, resourceid, fields = "", limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_geoinfo( variableid, resourceid, fields = "", limit = 25, offset = 0, query = "", orderby = "" )
variableid |
(string): Variable identificator. |
resourceid |
(string): Resource identificator. |
fields |
(string): Additional fields that you want to show in the answer. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_geoinfo("VR_TERRITORIO", "MUN_ICOD_VINOS")get_structuralresources_geoinfo("VR_TERRITORIO", "MUN_ICOD_VINOS")
This function returns data from /v1.0/variablefamilies
get_structuralresources_variable_families( limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_variable_families( limit = 25, offset = 0, query = "", orderby = "" )
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_variable_families()get_structuralresources_variable_families()
This function returns data from /v1.0/variablefamilies/{id}
get_structuralresources_variable_families_id(id)get_structuralresources_variable_families_id(id)
id |
(string): Variable family identificator. |
get_structuralresources_variable_families_id("VRF_DEMOGRAFICAS")get_structuralresources_variable_families_id("VRF_DEMOGRAFICAS")
This function returns data from /v1.0/variablefamilies/{id}/variables
get_structuralresources_variable_families_id_variables( id, limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_variable_families_id_variables( id, limit = 25, offset = 0, query = "", orderby = "" )
id |
(string): Variable family identificator. |
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_variable_families_id_variables("VRF_DEMOGRAFICAS")get_structuralresources_variable_families_id_variables("VRF_DEMOGRAFICAS")
This function returns data from /v1.0/variables/{variableID}/variableelements
get_structuralresources_variableelements( variableid, limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_variableelements( variableid, limit = 25, offset = 0, query = "", orderby = "" )
variableid |
(string) Variable identificator. |
limit |
(int) Results limit. By default |
offset |
(int) Displacement. Result from which it is returned. By default |
query |
(string) Query to filter the results. |
orderby |
(string) Field by which to sort the results. |
get_structuralresources_variableelements("VR_SEXO")get_structuralresources_variableelements("VR_SEXO")
This function returns data from /v1.0/variables/{variableID}/variableelements/{resourceID}
get_structuralresources_variableelements_resource(variableid, resourceid)get_structuralresources_variableelements_resource(variableid, resourceid)
variableid |
(string): Resource identificator. |
resourceid |
(string): Variable identificator. |
get_structuralresources_variableelements_resource("VR_SEXO", "FEMALE")get_structuralresources_variableelements_resource("VR_SEXO", "FEMALE")
This function returns data from /v1.0/variables
get_structuralresources_variables( limit = 25, offset = 0, query = "", orderby = "" )get_structuralresources_variables( limit = 25, offset = 0, query = "", orderby = "" )
limit |
(int): Results limit. By default |
offset |
(int): Displacement. Result from which it is returned. By default |
query |
(string): Query to filter the results. |
orderby |
(string): Field by which to sort the results. |
get_structuralresources_variables()get_structuralresources_variables()
This function returns data from /v1.0/variables/{id}
get_structuralresources_variables_id(id)get_structuralresources_variables_id(id)
id |
(string): Variable identifier. |
get_structuralresources_variables_id("VR_SEXO")get_structuralresources_variables_id("VR_SEXO")